--[[
WarlockReminder Beta Continued v1.20
06 Dec 2010
Author: CKlausi/Biny of Anetheron EU
Original Author of WarlockReminder: Vux of Dragonblight-US
Description: Reminds you of important Warlock-Buffs + Combatreminders
File: WarlockReminderConfig.lua
]]--

local WarlockReminder = LibStub("AceAddon-3.0"):GetAddon("WarlockReminder")
local L = LibStub("AceLocale-3.0"):GetLocale("WarlockReminder")

local AceConfigDialog = LibStub("AceConfigDialog-3.0")

-- Output frames
local OutputFrames = {
	["chat"] = L["Chat"],
	["blizzard"] = L["Blizzard Message Frame"],
	["wlrframe"] = L["WarlockReminder Frame"],
}
-- END Output frames

-- Options
local wlroptions = {
    name = "WarlockReminder",
    handler = WarlockReminder,
    type = 'group',
    args = {
		reminderheader = {
			type = "header",
			order = 0,
			name = L["Reminders"],
		},
        armor = {
            type = "toggle",
			order = 1,
            name = L["Armor"],
            desc = L["Show armor reminder"],
			get = "GetShowArmor",
			set = "SetShowArmor",
		},
		sl = {
            type = "toggle",
			order = 2,
            name = L["Soul Link"],
            desc = L["Show Soul Link reminder"],
			get = "GetShowSL",
			set = "SetShowSL",
		},
		pet = {
            type = "toggle",
			order = 3,
            name = L["Pet"],
            desc = L["Show pet reminder"],
			get = "GetShowPet",
			set = "SetShowPet",
		},
		flask = {
            type = "toggle",
			order = 4,
            name = L["Flask and Elixir"],
            desc = L["Show Flask and Elixir reminder"],
			get = "GetShowFlask",
			set = "SetShowFlask",
		},
		food = {
            type = "toggle",
			order = 5,
			width = "double",
            name = L["Well Fed"],
            desc = L["Show food reminder"],
			get = "GetShowFood",
			set = "SetShowFood",
		},
		outputframe = {
			type = "select",
			name = L["Output Frame"],
			desc = L["Reminders will be shown in the selected frame"],
			order = 6,
			values = OutputFrames,
			get = "GetOutputFrame",
			set = "SetOutputFrame",
		},
		anchorconfigshow = {
			type = "execute",
			name = L["Show anchor config"],
			desc = L["Show anchor config"],
			order = 7,
			func = "ShowAnchorConfig",
		},
		-- Dark Intent
		darkintentheader = {
			type = "header",
			order = 8,
			name = L["Dark Intent tracker"],
		},
		darkintentshow = {
            type = "toggle",
			order = 9,
            name = L["Show tracker"],
            desc = L["Show Dark Intent tracker"],
			get = "GetShowDarkIntent",
			set = "SetShowDarkIntent",
		},
		darkintentconfig = {
			type = "execute",
			name = L["Show Dark Intent config"],
			desc = L["Show Dark Intent config"],
			order = 10,
			func = "ShowDarkIntentConfig",
		},
		-- END Dark Intent
    },
}
-- END Options

-- Wlrcombat options
local wlrcombat = {
	name = L["Combat Reminder"],
	handler = WarlockReminder,
	type = 'group',
	args = {
		-- Drain Soul
		drainsoulheader = {
			type = "header",
			name = L["Drain Soul reminder"],
			order = 1,
		},
		drainsoulsound = {
			type = "toggle",
			name = L["Play sound reminder"],
			desc = L["Play Drain Soul sound reminder"],
			order = 2,
			get = "GetPlayDrainSoul",
			set = "SetPlayDrainSoul",
		},
		drainsoulmessage = {
			type = "toggle",
			name = L["Message reminder"],
			desc = L["Show Drain Soul message reminder"],
			order = 3,
			get = "GetShowDrainSoulMessage",
			set = "SetShowDrainSoulMessage",
		},
		drainsoulframe = {
			type = "toggle",
			name = L["Show Drain Soul Frame"],
			desc = L["Drain Soul will be shown in the WarlockReminder Frame"],
			order = 4,
			get = "GetShowDrainSoulFrame",
			set = "SetShowDrainSoulFrame",
		},
		drainsoulduration = {
			type = "range",
			name = L["Duration of Drain Soul Frame"],
			desc = L["How long the Drain Soul Frame will be shown"],
			order = 5,
			disabled = function(self) return not WarlockReminder:GetShowDrainSoulFrame("DrainSoulDuration") end,
			min = 0,
			max = 30,
			step = 1,
			isPercent = false,
			get = "GetDrainSoulDuration",
			set = "SetDrainSoulDuration",
		},
		drainsoulpercent = {
			type = "range",
			name = L["Show reminder at"],
			desc = L["Show Drain Soul reminder at"],
			order = 6,
			min = 0.0,
			max = 1.0,
			step = 0.01,
			isPercent = true,
			get = "GetDrainSoulPercent",
			set = "SetDrainSoulPercent",
		},
		drainsoulhealth = {
			type = "input",
			name = L["Minimum health"],
			desc = L["Minimum health to show the Drain Soul reminder"],
			order = 7,
			get = "GetDrainSoulHealth",
			set = "SetDrainSoulHealth",
		},
		-- END Drain Soul
		-- Decimation
		decimationheader = {
			type = "header",
			name = L["Decimation Reminder"],
			order = 8,
		},
		decimationsound = {
			type = "toggle",
			name = L["Play sound reminder"],
			desc = L["Play Decimation sound reminder"],
			order = 9,
			get = "GetPlayDecimationSound",
			set = "SetPlayDecimationSound",
		},
		decimationmessage = {
			type = "toggle",
			name = L["Message reminder"],
			desc = L["Show Decimation message reminder"],
			order = 10,
			get = "GetShowDecimationMessage",
			set = "SetShowDecimationMessage",
		},
		decimationframe = {
			type = "toggle",
			name = L["Show Decimation Frame"],
			desc = L["Show Decimation Frame"],
			order = 11,
			get = "GetShowDecimationFrame",
			set = "SetShowDecimationFrame",
		},
		-- END Decimation
		-- Molten Core
		moltencoreheader = {
			type = "header",
			name = L["Molten Core Reminder"],
			order = 12,
		},
		moltencoresound = {
			type = "toggle",
			name = L["Play sound reminder"],
			desc = L["Play Molten Core sound reminder"],
			order = 13,
			get = "GetPlayMoltenCoreSound",
			set = "SetPlayMoltenCoreSound",
		},
		moltencoremessage = {
			type = "toggle",
			name = L["Message reminder"],
			desc = L["Show Molten Core message reminder"],
			order = 14,
			get = "GetShowMoltenCoreMessage",
			set = "SetShowMoltenCoreMessage",
		},
		moltencoreframe = {
			type = "toggle",
			name = L["Show Molten Core Frame"],
			desc = L["Show Molten Core Frame"],
			order = 15,
			get = "GetShowMoltenCoreFrame",
			set = "SetShowMoltenCoreFrame",
		},
		-- END Molten Core
		-- Shadow Trance
		shadowtranceheader = {
			type = "header",
			name = L["Shadow Trance Reminder"],
			order = 16,
		},
		shadowtrancesound = {
			type = "toggle",
			name = L["Play sound reminder"],
			desc = L["Play Shadow Trance sound reminder"],
			order = 17,
			get = "GetPlayShadowTranceSound",
			set = "SetPlayShadowTranceSound",
		},
		shadowtrancemessage = {
			type = "toggle",
			name = L["Message reminder"],
			desc = L["Show Shadow Trance message reminder"],
			order = 18,
			get = "GetShowShadowTranceMessage",
			set = "SetShowShadowTranceMessage",
		},
		shadowtranceframe = {
			type = "toggle",
			name = L["Show Shadow Trance Frame"],
			desc = L["Show Shadow Trance Frame"],
			order = 19,
			get = "GetShowShadowTranceFrame",
			set = "SetShowShadowTranceFrame",
		},
		-- END Shadow Trance
		-- Empowered Imp
		empoweredimpheader = {
			type = "header",
			name = L["Empowered Imp Reminder"],
			order = 20,
		},
		empoweredimpsound = {
			type = "toggle",
			name = L["Play sound reminder"],
			desc = L["Play Empowered Imp sound reminder"],
			order = 21,
			get = "GetPlayEmpoweredImpSound",
			set = "SetPlayEmpoweredImpSound",
		},
		empoweredimpmessage = {
			type = "toggle",
			name = L["Message reminder"],
			desc = L["Show Empowered Imp message reminder"],
			order = 22,
			get = "GetShowEmpoweredImpMessage",
			set = "SetShowEmpoweredImpMessage",
		},
		empoweredimpframe = {
			type = "toggle",
			name = L["Show Empowered Imp Frame"],
			desc = L["Show Empowered Imp Frame"],
			order = 23,
			get = "GetShowEmpoweredImpFrame",
			set = "SetShowEmpoweredImpFrame",
		},
		-- END Empowered Imp
	}
}
-- END Wlrcombat options

-- Wlranchors options
local wlranchors = {
    name = L["WarlockReminder Frame"],
    handler = WarlockReminder,
    type = 'group',
    args = {
		anchorheader = {
			type = "header",
			name = L["Anchor"],
			order = 1,
		},
		anchorshow = {
			type = "execute",
			name = L["Anchor Show"],
			desc = L["Anchor Show"],
			order = 2,
			func = "ShowAnchor",
		},
		anchorreset = {
			type = "execute",
			name = L["Anchor Reset"],
			desc = L["Anchor Reset"],
			order = 3,
			func = "ResetAnchor",
		},
		frameheader = {
			type = "header",
			name = L["Frame"],
			order = 4,
		},
		framealpha = {
			type = "range",
			name = L["Frame alpha"],
			desc = L["Frame alpha"],
			order = 5,
			min = 0.0,
			softMin = 0.25,
			max = 1.0,
			step = 0.05,
			isPercent = true,
			get = "GetAnchorAlpha",
			set = "SetAnchorAlpha",
		},
		framesize = {
			type = "range",
			name = L["Frame size"],
			desc = L["Frame size"],
			order = 6,
			min = 0.01,
			softMin = 0.25,
			max = 3,
			softMax = 2,
			step = 0.01,
			isPercent = true,
			get = "GetAnchorSize",
			set = "SetAnchorSize",
		},
	}
}
-- END Wlranchors options

-- DiFrame options
local wlrdiframe = {
    name = L["Dark Intent tracker"],
    handler = WarlockReminder,
    type = 'group',
    args = {
		darkintentheader = {
			type = "header",
			name = L["Dark Intent tracker"],
			order = 1,
		},
		darkintentshow = {
			type = "execute",
			name = L["Show Dark Intent tracker"],
			desc = L["Show Dark Intent tracker"],
			order = 2,
			func = "ShowDiFrame",
		},
		darkintentreset = {
			type = "execute",
			name = L["Dark Intent tracker reset"],
			desc = L["Dark Intent tracker reset"],
			order = 3,
			func = "ResetDiFrame",
		},
		darkintentheader = {
			type = "header",
			name = L["Tracker"],
			order = 4,
		},
		darkintentlock = {
			type = "toggle",
			name = L["Lock frame"],
			desc = L["Lock frame"],
			order = 5,
			get = "GetDarkIntentLock",
			set = "SetDarkIntentLock",
		},
		darkintentrealm = {
			type = "toggle",
			name = L["Show realm"],
			desc = L["Show realm"],
			order = 6,
			get = "GetDarkIntentShowRealm",
			set = "SetDarkIntentShowRealm",
		},
		darkintentalpha = {
			type = "range",
			name = L["Frame alpha"],
			desc = L["Frame alpha"],
			order = 7,
			min = 0.0,
			softMin = 0.25,
			max = 1.0,
			step = 0.05,
			isPercent = true,
			get = "GetDiFrameAlpha",
			set = "SetDiFrameAlpha",
		},
		darkintentbgalpha = {
			type = "range",
			name = L["Background alpha"],
			desc = L["Background alpha"],
			order = 8,
			min = 0.0,
			max = 1.0,
			step = 0.05,
			isPercent = true,
			get = "GetDiBgAlpha",
			set = "SetDiBgAlpha",
		},
		darkintentsize = {
			type = "range",
			name = L["Frame size"],
			desc = L["Frame size"],
			order = 9,
			min = 0.01,
			softMin = 0.5,
			max = 3,
			softMax = 2,
			step = 0.01,
			isPercent = true,
			get = "GetDiFrameSize",
			set = "SetDiFrameSize",
		},
		darkintentextrawidth = {
			type = "range",
			name = L["Extra width"],
			desc = L["Extra width"],
			order = 10,
			min = 0.00,
			max = 500,
			softMax = 100,
			step = 1,
			get = "GetDiExtraWidth",
			set = "SetDiExtraWidth",
		},
		darkintentfontsize = {
			type = "range",
			name = L["Font size"],
			desc = L["Font size"],
			order = 11,
			min = 0.00,
			softMin = 7,
			max = 30,
			step = 1,
			get = "GetDiFontSize",
			set = "SetDiFontSize",
		},
	}
}
-- END diframe options


-- If "wlrframe" is selected returns false, otherwise true
function WarlockReminder:ShowAnchorOptions()
	if self:GetOutputFrame() == "wlrframe" then return false
	else return true end
end

-- Show anchor config menu
function WarlockReminder:ShowAnchorConfig()
	local currentFrame = InterfaceOptionsFrame
	while currentFrame do
		local lastFrame = currentFrame.lastFrame
		HideUIPanel(currentFrame)
		currentFrame = lastFrame
	end
	wlranchor:Show()
	self:WlrFrame(true, FelArmor)
	LibStub("AceConfigDialog-3.0"):Open("WarlockReminderFrameConfig")
end

-- Show the anchor
function WarlockReminder:ShowAnchor()
	wlranchor:Show()
end

-- Show diFrame config menu
function WarlockReminder:ShowDarkIntentConfig()
	local currentFrame = InterfaceOptionsFrame
	while currentFrame do
		local lastFrame = currentFrame.lastFrame
		HideUIPanel(currentFrame)
		currentFrame = lastFrame
	end
	diFrame:Show()
	LibStub("AceConfigDialog-3.0"):Open("WarlockReminderDiFrameConfig")
end

-- Show the diFrame
function WarlockReminder:ShowDiFrame()
	diFrame:Show()
end


-- Chat command handling
function WarlockReminder:ChatCommand(input)
	-- show config menu or handle chat commands
    if not input or input:trim() == "config" or input:trim() == "" then
        InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
	else
        LibStub("AceConfigCmd-3.0").HandleCommand(WarlockReminder, "wlr", "WarlockReminder", input)
    end
end

-- New Profile
function WarlockReminder:NewConfig(db, profile)
	self:ResetAnchor()
	self:ResetDiFrame()
end

-- Profile changes
function WarlockReminder:RefreshConfig(db, newProfile)
	-- Set the anchor position
	wlranchor:ClearAllPoints()
	wlranchor:SetPoint("TOPLEFT",UIParent,"BOTTOMLEFT", self.db.profile.wlrAnchorLeft, self.db.profile.wlrAnchorTop)
	self:FramesToAnchor()
	wlrframe:SetAlpha(self.db.profile.wlrAnchorAlpha)
	wlrframe:SetWidth(48*self.db.profile.wlrAnchorSize)
	wlrframe:SetHeight(48*self.db.profile.wlrAnchorSize)
	
	-- Set the diFrame position
	self:DiFrameSetup()
end

-- Setup options
function WarlockReminder:SetUpOptions()
	local wlrprofile = LibStub('AceDBOptions-3.0'):GetOptionsTable(self.db)
	-- Add dual-spec support
	local LibDualSpec = LibStub("LibDualSpec-1.0", true)
	if LibDualSpec then
		LibDualSpec:EnhanceDatabase(self.db, "WarlockReminder")
		LibDualSpec:EnhanceOptions(wlrprofile, self.db)
	end
	
	-- Add option windows
    LibStub("AceConfig-3.0"):RegisterOptionsTable("WarlockReminder", wlroptions)
	-- Seperate config for the wlrframe
	LibStub("AceConfig-3.0"):RegisterOptionsTable("WarlockReminderFrameConfig", wlranchors)
	AceConfigDialog:SetDefaultSize("WarlockReminderFrameConfig", 200,300)
	-- Seperate config for the diFrame
	LibStub("AceConfig-3.0"):RegisterOptionsTable("WarlockReminderDiFrameConfig", wlrdiframe)
	AceConfigDialog:SetDefaultSize("WarlockReminderDiFrameConfig", 200,430)
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("WarlockReminderCombat", wlrcombat)
	LibStub("AceConfig-3.0"):RegisterOptionsTable("WarlockReminderProfiles", wlrprofile)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("WarlockReminder", "WarlockReminder")
	self.optionsFrameCombat = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("WarlockReminderCombat", L["Combat Reminder"], "WarlockReminder")
	self.optionsFrameProfile = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("WarlockReminderProfiles", L["Profiles"], "WarlockReminder")
	
	-- Register chat commands
	self:RegisterChatCommand("wlr", "ChatCommand")
    self:RegisterChatCommand("warlockreminder", "ChatCommand")
end
-- END Setup options


-- returns enabled or disabled for output
function WarlockReminder:GetOptionStatus(status)
	if status then
		return L["Enabled"]
	else
		return L["Disabled"]
	end
end

-- Armor
function WarlockReminder:GetShowArmor(info)
    return self.db.profile.showArmor
end

function WarlockReminder:SetShowArmor(info, newValue)
    self.db.profile.showArmor = newValue
	self:Print(L["Show armor reminder"] .. " " .. self:GetOptionStatus(self:GetShowArmor()))
	self:Reminder()
end

-- Soul Link
function WarlockReminder:GetShowSL(info)
    return self.db.profile.showSL
end

function WarlockReminder:SetShowSL(info, newValue)
    self.db.profile.showSL = newValue
	self:Print(L["Show Soul Link reminder"] .. " " .. self:GetOptionStatus(self:GetShowSL()))
	self:Reminder()
end

-- Flask
function WarlockReminder:GetShowFlask(info)
    return self.db.profile.showFlask
end

function WarlockReminder:SetShowFlask(info, newValue)
    self.db.profile.showFlask = newValue
	self:Print(L["Show Flask and Elixir reminder"] .. " " .. self:GetOptionStatus(self:GetShowFlask()))
	self:Reminder()
end

-- Pet
function WarlockReminder:GetShowPet(info)
    return self.db.profile.showPet
end

function WarlockReminder:SetShowPet(info, newValue)
    self.db.profile.showPet = newValue
	self:Print(L["Show pet reminder"] .. " " .. self:GetOptionStatus(self:GetShowPet()))
	self:Reminder()
end

-- Food
function WarlockReminder:GetShowFood(info)
    return self.db.profile.showFood
end

function WarlockReminder:SetShowFood(info, newValue)
    self.db.profile.showFood = newValue
	self:Print(L["Show food reminder"] .. " " .. self:GetOptionStatus(self:GetShowFood()))
	self:Reminder()
end

-- Output Frame
function WarlockReminder:GetOutputFrame(info)
    return self.db.profile.outputFrame
end

function WarlockReminder:SetOutputFrame(info, newValue)
    self.db.profile.outputFrame = newValue
	self:Print(L["Output Frame"] .. ": " .. OutputFrames[self:GetOutputFrame()])
	self:DrainSoulReminder()
end

-- WlrFrame Position
function WarlockReminder:GetWlrAnchorTop(info)
    return self.db.profile.wlrAnchorTop
end

function WarlockReminder:SetWlrAnchorTop(info, newValue)
    self.db.profile.wlrAnchorTop = newValue
end

function WarlockReminder:GetWlrAnchorLeft(info)
    return self.db.profile.wlrAnchorLeft
end

function WarlockReminder:SetWlrAnchorLeft(info, newValue)
    self.db.profile.wlrAnchorLeft = newValue
end
-- END WlrFrame

-- WlrFrame Config
function WarlockReminder:GetAnchorAlpha(info)
    return self.db.profile.wlrAnchorAlpha
end

function WarlockReminder:SetAnchorAlpha(info, newValue)
	wlrframe:SetAlpha(newValue)
    self.db.profile.wlrAnchorAlpha = newValue
end

function WarlockReminder:GetAnchorSize(info)
    return self.db.profile.wlrAnchorSize
end

function WarlockReminder:SetAnchorSize(info, newValue)
	wlrframe:SetWidth(48*newValue)
	wlrframe:SetHeight(48*newValue)
    self.db.profile.wlrAnchorSize = newValue
end
-- END WlrFrame Config

-- Drain Soul
-- Play ds sound
function WarlockReminder:GetPlayDrainSoul(info)
    return self.db.profile.playDrainSoul
end

function WarlockReminder:SetPlayDrainSoul(info, newValue)
    self.db.profile.playDrainSoul = newValue
	self:Print(L["Play Drain Soul sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayDrainSoul()))
	self:DrainSoulReminder()
end

-- Show ds message
function WarlockReminder:GetShowDrainSoulMessage(info)
    return self.db.profile.showDrainSoulMessage
end

function WarlockReminder:SetShowDrainSoulMessage(info, newValue)
    self.db.profile.showDrainSoulMessage = newValue
	self:Print(L["Show Drain Soul message reminder"] .. " " .. self:GetOptionStatus(self:GetShowDrainSoulMessage()))
	self:DrainSoulReminder()
end

-- Show ds reminder at x%
function WarlockReminder:GetDrainSoulPercent(info)
    return self.db.profile.drainSoulPercent
end

function WarlockReminder:SetDrainSoulPercent(info, newValue)
    self.db.profile.drainSoulPercent = newValue
end

-- Minimum Health
function WarlockReminder:GetDrainSoulHealth(info)
    return self.db.profile.drainSoulHealth
end

function WarlockReminder:SetDrainSoulHealth(info, newValue)
    self.db.profile.drainSoulHealth = newValue
	self:Print(L["Minimum health"] .. ": " .. self:GetDrainSoulHealth())
	self:DrainSoulReminder()
end

-- Drain Soul Frame Show
function WarlockReminder:GetShowDrainSoulFrame(info)
    return self.db.profile.showDrainSoulFrame
end

function WarlockReminder:SetShowDrainSoulFrame(info, newValue)
    self.db.profile.showDrainSoulFrame = newValue
	self:DrainSoulReminder()
end

-- Drain Soul Frame Duration
function WarlockReminder:GetDrainSoulDuration(info)
    return self.db.profile.drainSoulDuration
end

function WarlockReminder:SetDrainSoulDuration(info, newValue)
    self.db.profile.drainSoulDuration = newValue
	self:DrainSoulReminder()
end
-- END Drain Soul

-- Decimation
-- Decimation play sound
function WarlockReminder:GetPlayDecimationSound(info)
    return self.db.profile.playDecimationSound
end

function WarlockReminder:SetPlayDecimationSound(info, newValue)
    self.db.profile.playDecimationSound = newValue
	self:Print(L["Play Decimation sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayDecimationSound()))
end

-- Decimation Message Show
function WarlockReminder:GetShowDecimationMessage(info)
    return self.db.profile.showDecimationMessage
end

function WarlockReminder:SetShowDecimationMessage(info, newValue)
    self.db.profile.showDecimationMessage = newValue
	self:Print(L["Show Decimation message reminder"] .. " " .. self:GetOptionStatus(self:GetShowDecimationMessage()))
end

-- Decimation Frame Show
function WarlockReminder:GetShowDecimationFrame(info)
    return self.db.profile.showDecimationFrame
end

function WarlockReminder:SetShowDecimationFrame(info, newValue)
    self.db.profile.showDecimationFrame = newValue
	self:Print(L["Show Decimation Frame"] .. " " .. self:GetOptionStatus(self:GetShowDecimationFrame()))
end
-- END Decimation

-- Molten Core
-- Molten Core play sound
function WarlockReminder:GetPlayMoltenCoreSound(info)
    return self.db.profile.playMoltenCoreSound
end

function WarlockReminder:SetPlayMoltenCoreSound(info, newValue)
    self.db.profile.playMoltenCoreSound = newValue
	self:Print(L["Play Molten Core sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayMoltenCoreSound()))
end

-- Molten Core Message Show
function WarlockReminder:GetShowMoltenCoreMessage(info)
    return self.db.profile.showMoltenCoreMessage
end

function WarlockReminder:SetShowMoltenCoreMessage(info, newValue)
    self.db.profile.showMoltenCoreMessage = newValue
	self:Print(L["Show Molten Core message reminder"] .. " " .. self:GetOptionStatus(self:GetShowMoltenCoreMessage()))
end

-- Molten Core Frame Show
function WarlockReminder:GetShowMoltenCoreFrame(info)
    return self.db.profile.showMoltenCoreFrame
end

function WarlockReminder:SetShowMoltenCoreFrame(info, newValue)
    self.db.profile.showMoltenCoreFrame = newValue
	self:Print(L["Show Molten Core Frame"] .. " " .. self:GetOptionStatus(self:GetShowMoltenCoreFrame()))
end
-- END Molten Core

-- Shadow Trance
-- Shadow Trance play sound
function WarlockReminder:GetPlayShadowTranceSound(info)
    return self.db.profile.playShadowTranceSound
end

function WarlockReminder:SetPlayShadowTranceSound(info, newValue)
    self.db.profile.playShadowTranceSound = newValue
	self:Print(L["Play Shadow Trance sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayShadowTranceSound()))
end

-- Shadow Trance Message Show
function WarlockReminder:GetShowShadowTranceMessage(info)
    return self.db.profile.showShadowTranceMessage
end

function WarlockReminder:SetShowShadowTranceMessage(info, newValue)
    self.db.profile.showShadowTranceMessage = newValue
	self:Print(L["Show Shadow Trance message reminder"] .. " " .. self:GetOptionStatus(self:GetShowShadowTranceMessage()))
end

-- Shadow Trance Frame Show
function WarlockReminder:GetShowShadowTranceFrame(info)
    return self.db.profile.showShadowTranceFrame
end

function WarlockReminder:SetShowShadowTranceFrame(info, newValue)
    self.db.profile.showShadowTranceFrame = newValue
	self:Print(L["Show Shadow Trance Frame"] .. " " .. self:GetOptionStatus(self:GetShowShadowTranceFrame()))
end
-- END Shadow Trance

-- Empowered Imp
-- Empowered Imp play sound
function WarlockReminder:GetPlayEmpoweredImpSound(info)
    return self.db.profile.playEmpoweredImpSound
end

function WarlockReminder:SetPlayEmpoweredImpSound(info, newValue)
    self.db.profile.playEmpoweredImpSound = newValue
	self:Print(L["Play Empowered Imp sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayEmpoweredImpSound()))
end

-- Empowered Imp Message Show
function WarlockReminder:GetShowEmpoweredImpMessage(info)
    return self.db.profile.showEmpoweredImpMessage
end

function WarlockReminder:SetShowEmpoweredImpMessage(info, newValue)
    self.db.profile.showEmpoweredImpMessage = newValue
	self:Print(L["Show Empowered Imp message reminder"] .. " " .. self:GetOptionStatus(self:GetShowEmpoweredImpMessage()))
end

-- Empowered Imp Frame Show
function WarlockReminder:GetShowEmpoweredImpFrame(info)
    return self.db.profile.showEmpoweredImpFrame
end

function WarlockReminder:SetShowEmpoweredImpFrame(info, newValue)
    self.db.profile.showEmpoweredImpFrame = newValue
	self:Print(L["Show Empowered Imp Frame"] .. " " .. self:GetOptionStatus(self:GetShowEmpoweredImpFrame()))
end
-- END Empowered Imp

-- Dark Intent
function WarlockReminder:GetShowDarkIntent(info)
    return self.db.profile.showDarkIntentFrame
end

function WarlockReminder:SetShowDarkIntent(info, newValue)
    self.db.profile.showDarkIntentFrame = newValue
	self:Print(L["Show Dark Intent tracker"] .. " " .. self:GetOptionStatus(self:GetShowDarkIntent()))
	self:DiFrameSetup()
end

-- diFrame Position
function WarlockReminder:GetDiFrameTop(info)
    return self.db.profile.diFrameTop
end

function WarlockReminder:SetDiFrameTop(info, newValue)
    self.db.profile.diFrameTop = newValue
end

function WarlockReminder:GetDiFrameLeft(info)
    return self.db.profile.diFrameLeft
end

function WarlockReminder:SetDiFrameLeft(info, newValue)
    self.db.profile.diFrameLeft = newValue
end

-- diFrame Config
function WarlockReminder:GetDiFrameAlpha(info)
    return self.db.profile.diFrameAlpha
end

function WarlockReminder:SetDiFrameAlpha(info, newValue)
    self.db.profile.diFrameAlpha = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDiBgAlpha(info)
    return self.db.profile.diBgAlpha
end

function WarlockReminder:SetDiBgAlpha(info, newValue)
    self.db.profile.diBgAlpha = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDiFrameSize(info)
    return self.db.profile.diFrameSize
end

function WarlockReminder:SetDiFrameSize(info, newValue)
    self.db.profile.diFrameSize = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDiExtraWidth(info)
    return self.db.profile.diExtraWidth
end

function WarlockReminder:SetDiExtraWidth(info, newValue)
    self.db.profile.diExtraWidth = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDarkIntentLock(info)
    return self.db.profile.diFrameLock
end

function WarlockReminder:SetDarkIntentLock(info, newValue)
    self.db.profile.diFrameLock = newValue
	if(newValue == true) then 
		diFrame:SetMovable(0)
	else 
		diFrame:SetMovable(1) 
	end
end

function WarlockReminder:GetDarkIntentShowRealm(info)
    return self.db.profile.diFrameShowRealm
end

function WarlockReminder:SetDarkIntentShowRealm(info, newValue)
    self.db.profile.diFrameShowRealm = newValue
end

function WarlockReminder:GetDiFontSize(info)
    return self.db.profile.diFontSize
end

function WarlockReminder:SetDiFontSize(info, newValue)
    self.db.profile.diFontSize = newValue
	self:DiFrameSetup()
end
-- End Dark Intent
